{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/annotation"
                },
                {
                    "type": "Directory",
                    "id": "#main/hisat2_idx_basedir"
                },
                {
                    "type": "string",
                    "id": "#main/hisat2_idx_basename"
                },
                {
                    "type": "int",
                    "id": "#main/nthreads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/repo"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/run_ids"
                }
            ],
            "steps": [
                {
                    "run": "#cufflinks.cwl",
                    "in": [
                        {
                            "source": "#main/annotation",
                            "id": "#main/cufflinks/annotation"
                        },
                        {
                            "source": "#main/samtools_sort/sorted_bamfile",
                            "id": "#main/cufflinks/input_bam"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/cufflinks/nthreads"
                        }
                    ],
                    "out": [
                        "#main/cufflinks/cufflinks_result"
                    ],
                    "id": "#main/cufflinks"
                },
                {
                    "run": "#download-sra.cwl",
                    "in": [
                        {
                            "source": "#main/repo",
                            "id": "#main/download-sra/repo"
                        },
                        {
                            "source": "#main/run_ids",
                            "id": "#main/download-sra/run_ids"
                        }
                    ],
                    "out": [
                        "#main/download-sra/sraFiles"
                    ],
                    "id": "#main/download-sra"
                },
                {
                    "run": "#hisat2_mapping_pe.cwl",
                    "in": [
                        {
                            "source": "#main/pfastq-dump/forward",
                            "id": "#main/hisat2_mapping/fq1"
                        },
                        {
                            "source": "#main/pfastq-dump/reverse",
                            "id": "#main/hisat2_mapping/fq2"
                        },
                        {
                            "source": "#main/hisat2_idx_basedir",
                            "id": "#main/hisat2_mapping/hisat2_idx_basedir"
                        },
                        {
                            "source": "#main/hisat2_idx_basename",
                            "id": "#main/hisat2_mapping/hisat2_idx_basename"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/hisat2_mapping/nthreads"
                        }
                    ],
                    "out": [
                        "#main/hisat2_mapping/hisat2_sam"
                    ],
                    "id": "#main/hisat2_mapping"
                },
                {
                    "run": "#pfastq-dump.cwl",
                    "in": [
                        {
                            "source": "#main/nthreads",
                            "id": "#main/pfastq-dump/nthreads"
                        },
                        {
                            "source": "#main/download-sra/sraFiles",
                            "id": "#main/pfastq-dump/sraFiles"
                        }
                    ],
                    "out": [
                        "#main/pfastq-dump/forward",
                        "#main/pfastq-dump/reverse"
                    ],
                    "id": "#main/pfastq-dump"
                },
                {
                    "run": "#samtools_sam2bam.cwl",
                    "in": [
                        {
                            "source": "#main/hisat2_mapping/hisat2_sam",
                            "id": "#main/samtools_sam2bam/input_sam"
                        }
                    ],
                    "out": [
                        "#main/samtools_sam2bam/bamfile"
                    ],
                    "id": "#main/samtools_sam2bam"
                },
                {
                    "run": "#samtools_sort.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_sam2bam/bamfile",
                            "id": "#main/samtools_sort/input_bam"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/samtools_sort/nthreads"
                        }
                    ],
                    "out": [
                        "#main/samtools_sort/sorted_bamfile"
                    ],
                    "id": "#main/samtools_sort"
                }
            ],
            "id": "#main",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/cufflinks/cufflinks_result",
                    "id": "#main/cufflinks_result"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Cufflinks: Transcriptome assembly and differential expression analysis for RNA-Seq",
            "doc": "Transcriptome assembly and differential expression analysis for RNA-Seq. http://cole-trapnell-lab.github.io/cufflinks/cufflinks/index.html",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/cufflinks:2.2.1--py27_2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "cufflinks",
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "label": "quantitate against reference transcript annotations",
                    "doc": "quantitate against reference transcript annotations",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--GTF"
                    },
                    "id": "#cufflinks.cwl/annotation"
                },
                {
                    "label": "Input bam file for cufflinks",
                    "doc": "Input bam file for cufflinks",
                    "type": "File",
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#cufflinks.cwl/input_bam"
                },
                {
                    "label": "number of threads used during analysis",
                    "doc": "number of threads used during analysis",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#cufflinks.cwl/nthreads"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#cufflinks.cwl/cufflinks_result"
                }
            ],
            "id": "#cufflinks.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "download-sra: A simple download tool to get .sra file",
            "doc": "A simple download tool to get .sra file from a repository of INSDC members. https://github.com/inutano/download-sra",
            "hints": [
                {
                    "dockerPull": "ghcr.io/inutano/download-sra:a827d85",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "download-sra"
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "ddbj",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "id": "#download-sra.cwl/repo"
                },
                {
                    "type": [
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#download-sra.cwl/run_ids"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*sra"
                    },
                    "id": "#download-sra.cwl/sraFiles"
                }
            ],
            "id": "#download-sra.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "HISAT2: graph-based alignment of next generation sequencing reads to a population of genomes [cwl for paired end read]",
            "doc": "HISAT2: graph-based alignment of next generation sequencing reads to a population of genomes. https://ccb.jhu.edu/software/hisat2/manual.shtml#command-line",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/hisat2:2.1.0--py36h2d50403_1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "hisat2"
            ],
            "arguments": [
                {
                    "prefix": "-S",
                    "valueFrom": "$(runtime.outdir)/$(inputs.out_sam_name)"
                },
                {
                    "prefix": "-x",
                    "valueFrom": "$(inputs.hisat2_idx_basedir.path)/$(inputs.hisat2_idx_basename)"
                }
            ],
            "inputs": [
                {
                    "label": "Report alignments tailored for transcript assemblers",
                    "doc": "Report alignments tailored for transcript assemblers including StringTie. With this option, HISAT2 requires longer anchor lengths for de novo discovery of splice sites. This leads to fewer alignments with short-anchors, which helps transcript assemblers improve significantly in computation and memory usage.",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--downstream-transcriptome-assembly"
                    },
                    "id": "#hisat2_mapping_pe.cwl/dta"
                },
                {
                    "label": "Report alignments tailored specifically for Cufflinks",
                    "doc": "Report alignments tailored specifically for Cufflinks. In addition to what HISAT2 does with the above option (--dta), With this option, HISAT2 looks for novel splice sites with three signals (GT/AG, GC/AG, AT/AC), but all user-provided splice sites are used irrespective of their signals. HISAT2 produces an optional field, XS:A:[+-], for every spliced alignment",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--dta-cufflinks"
                    },
                    "id": "#hisat2_mapping_pe.cwl/dta_cufflinks"
                },
                {
                    "label": "Read file containing mate 1s",
                    "doc": "Comma-separated list of files containing mate 1s (filename usually includes _1), e.g. -1 flyA_1.fq,flyB_1.fq. Sequences specified with this option must correspond file-for-file and read-for-read with those specified in <m2>. Reads may be a mix of different lengths.",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#hisat2_mapping_pe.cwl/fq1"
                },
                {
                    "label": "Read file containing mate 2s",
                    "doc": "Comma-separated list of files containing mate 2s (filename usually includes _2), e.g. -2 flyA_2.fq,flyB_2.fq. Sequences specified with this option must correspond file-for-file and read-for-read with those specified in <m1>. Reads may be a mix of different lengths. ",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#hisat2_mapping_pe.cwl/fq2"
                },
                {
                    "label": "Path to the directory the index for the reference genome are in",
                    "doc": "Path to the directory the index for the index files, such as .1.ht2 / etc exist.",
                    "type": "Directory",
                    "id": "#hisat2_mapping_pe.cwl/hisat2_idx_basedir"
                },
                {
                    "label": "Basename of the hisat2 index files",
                    "doc": "Basename of the hisat2 index files, not including extensions like .1.ht2",
                    "type": "string",
                    "id": "#hisat2_mapping_pe.cwl/hisat2_idx_basename"
                },
                {
                    "label": "Launch NTHREADS parallel search threads",
                    "doc": "Launch NTHREADS parallel search threads (default: 1). Threads will run on separate processors/cores and synchronize when parsing reads and outputting alignments. Searching for alignments is highly parallel, and speedup is close to linear. Increasing -p increases HISAT2's memory footprint. E.g. when aligning to a human genome index, increasing -p from 1 to 8 increases the memory footprint by a few hundred megabytes. This option is only available if bowtie is linked with the pthreads library (i.e. if BOWTIE_PTHREADS=0 is not specified at build time).",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "id": "#hisat2_mapping_pe.cwl/nthreads"
                },
                {
                    "label": "Name of file to write SAM alignments to",
                    "doc": "Name of file to write SAM alignments to (default: out.sam)",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out.sam",
                    "id": "#hisat2_mapping_pe.cwl/out_sam_name"
                },
                {
                    "label": "Print the wall-clock time",
                    "doc": "Print the wall-clock time required to load the index files and align the reads. This is printed to the 'standard error' ('stderr') filehandle.",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--time"
                    },
                    "id": "#hisat2_mapping_pe.cwl/time"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_sam_name)"
                    },
                    "id": "#hisat2_mapping_pe.cwl/hisat2_sam"
                }
            ],
            "id": "#hisat2_mapping_pe.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "pfastq-dump: A bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper",
            "doc": "pfastq-dump is a bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper. --stdout option is additionally supported, but almost same features. It also uses -N and -X options of fastq-dump to specify blocks of data to be decompressed separately. https://github.com/inutano/pfastq-dump",
            "hints": [
                {
                    "dockerPull": "quay.io/inutano/sra-toolkit:v2.9.0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "pfastq-dump"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--gzip"
                    },
                    "id": "#pfastq-dump.cwl/gzip"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#pfastq-dump.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--readids"
                    },
                    "id": "#pfastq-dump.cwl/readids"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--skip-technical"
                    },
                    "id": "#pfastq-dump.cwl/skip_technical"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-files"
                    },
                    "id": "#pfastq-dump.cwl/split_files"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-spot"
                    },
                    "id": "#pfastq-dump.cwl/split_spot"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#pfastq-dump.cwl/sraFiles"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*fastq*"
                    },
                    "id": "#pfastq-dump.cwl/fastqFiles"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_1.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/forward"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_2.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/reverse"
                }
            ],
            "id": "#pfastq-dump.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h46bd0b3_0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b"
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_filename)"
                }
            ],
            "inputs": [
                {
                    "label": "SAM format input file",
                    "doc": "SAM format input file",
                    "type": "File",
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#samtools_sam2bam.cwl/input_sam"
                },
                {
                    "label": "Filename to write output to",
                    "doc": "Filename to write output to",
                    "type": "string",
                    "default": "out.bam",
                    "id": "#samtools_sam2bam.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#samtools_sam2bam.cwl/bamfile"
                }
            ],
            "id": "#samtools_sam2bam.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h46bd0b3_0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_filename)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#samtools_sort.cwl/input_bam"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools_sort.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": "sorted.bam",
                    "id": "#samtools_sort.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#samtools_sort.cwl/sorted_bamfile"
                }
            ],
            "id": "#samtools_sort.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.18.owl",
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
